Crate simbld_http

Re-exports

Modules

Macros

  • This Rust code defines a macro generate_http_response_functions that generates response functions for enums implementing the ResponseFunctions trait. Here’s a breakdown of what the macro does:

Traits

Derive Macros

  • Creates a new type that iterates of the variants of an enum.